# The Kalzium solver needs OCaml with native compilation support (ocamlopt) and
# ocaml-facile.
%ifarch %{arm} %{ix86} x86_64 ppc ppc64 sparc sparcv9
%define with_facile 1
%endif
%if 0%{?fuduntu} < 2013
# native compilation for alpha and ia64 dropped in Fedora 18
%ifarch alpha ia64
%define with_facile 1
%endif
%endif

Name:    kalzium
Summary: Periodic Table of Elements 
Version: 4.10.2
Release: 1%{?dist}

License: GPLv2+
URL:     https://projects.kde.org/projects/kde/kdeedu/%{name}
%global revision %(echo %{version} | cut -d. -f3)
%if %{revision} >= 50
%global stable unstable
%else
%global stable stable
%endif
Source0: http://download.kde.org/%{stable}/%{version}/src/%{name}-%{version}.tar.xz

BuildRequires: avogadro-devel
BuildRequires: desktop-file-utils
BuildRequires: kdelibs4-devel >= %{version}
BuildRequires: libkdeedu-devel >= %{version}
%if 0%{?with_facile}
BuildRequires: ocaml(compiler)
BuildRequires: ocaml-facile-devel
%endif
BuildRequires: pkgconfig(eigen2)
BuildRequires: pkgconfig(openbabel-2.0)
BuildRequires: python-devel python

Requires: %{name}-libs%{?_isa} = %{version}-%{release}
Requires: kde-runtime%{?_kde4_version: >= %{_kde4_version}}

%description
%{summary}.

%package  libs
Summary:  Runtime files for %{name}
Requires: %{name} = %{version}-%{release}
Requires: libkdeedu%{?_isa} >= %{version}
%description libs
%{summary}.

%package devel
Summary:  Development files for %{name}
Requires: %{name}-libs%{?_isa} = %{version}-%{release}
Requires: libkdeedu-devel 
%description devel
%{summary}.


%prep
%setup -q


%build
mkdir -p %{_target_platform}
pushd %{_target_platform}
%{cmake_kde4} ..
popd

make %{?_smp_mflags} -C %{_target_platform}


%install
make install/fast DESTDIR=%{buildroot} -C %{_target_platform}

%find_lang %{name} --with-kde --without-mo


%check
desktop-file-validate %{buildroot}%{_kde4_datadir}/applications/kde4/kalzium.desktop
desktop-file-validate %{buildroot}%{_kde4_datadir}/applications/kde4/kalzium_cml.desktop


%post
touch --no-create %{_kde4_iconsdir}/hicolor &> /dev/null || :

%posttrans
gtk-update-icon-cache %{_kde4_iconsdir}/hicolor &> /dev/null || :
update-desktop-database -q &> /dev/null ||:

%postun
if [ $1 -eq 0 ] ; then
touch --no-create %{_kde4_iconsdir}/hicolor &> /dev/null || :
gtk-update-icon-cache %{_kde4_iconsdir}/hicolor &> /dev/null || :
update-desktop-database -q &> /dev/null ||:
fi

%files -f %{name}.lang
%doc COPYING
%{_kde4_bindir}/kalzium
%{_kde4_appsdir}/kalzium/
%{_kde4_datadir}/kde4/services/plasma-dataengine-kalzium.desktop
%{_kde4_libdir}/kde4/concentrationCalculator.so
%{_kde4_libdir}/kde4/gasCalculator.so
%{_kde4_libdir}/kde4/nuclearCalculator.so
%{_kde4_libdir}/kde4/plasma_applet_didyouknow.so
%{_kde4_libdir}/kde4/plasma_applet_molmassCalculator.so
%{_kde4_libdir}/kde4/plasma_engine_kalzium.so
%{_kde4_datadir}/applications/kde4/kalzium.desktop
%{_kde4_datadir}/applications/kde4/kalzium_cml.desktop
%{_kde4_datadir}/config.kcfg/kalzium.kcfg
%{_kde4_configdir}/kalzium.knsrc
%{_kde4_iconsdir}/hicolor/*/*/kalzium.*
%{_mandir}/man1/kalzium.*
%{_kde4_appsdir}/desktoptheme/default/widgets/chalkboard.svg
%{_kde4_appsdir}/libkdeedu/data/
%{_kde4_datadir}/kde4/services/concentrationCalculator.desktop
%{_kde4_datadir}/kde4/services/gasCalculator.desktop
%{_kde4_datadir}/kde4/services/nuclearCalculator.desktop
%{_kde4_datadir}/kde4/services/plasma-applet-Molmasscalculator.desktop
%{_kde4_datadir}/kde4/services/plasma_didyouknow.desktop

%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig

%files libs
%{_kde4_libdir}/libcompoundviewer.so.4*
%{_kde4_libdir}/libscience.so.4*

%files devel
%{_kde4_includedir}/libkdeedu/*.h
%{_kde4_libdir}/libcompoundviewer.so
%{_kde4_libdir}/libscience.so


%changelog
* Tue Apr 09 2013 Shawn W Dunn <sfalken@fuduntu.org> - 4.10.2-1
- Built for Fuduntu

* Sun Mar 31 2013 Rex Dieter <rdieter@fedoraproject.org> - 4.10.2-1
- 4.10.2

* Sat Mar 02 2013 Rex Dieter <rdieter@fedoraproject.org> - 4.10.1-1
- 4.10.1

* Sun Feb 10 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 4.10.0-3
- Rebuild for Boost-1.53.0

* Sat Feb 09 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 4.10.0-2
- Rebuild for Boost-1.53.0

* Fri Feb 01 2013 Rex Dieter <rdieter@fedoraproject.org> - 4.10.0-1
- 4.10.0

* Tue Jan 22 2013 Rex Dieter <rdieter@fedoraproject.org> - 4.9.98-1
- 4.9.98

* Fri Jan 04 2013 Rex Dieter <rdieter@fedoraproject.org> - 4.9.97-1
- 4.9.97

* Thu Dec 20 2012 Rex Dieter <rdieter@fedoraproject.org> - 4.9.95-1
- 4.9.95

* Thu Dec 13 2012 Adam Jackson <ajax@redhat.com> - 4.9.90-2
- Rebuild for glew 1.9.0

* Tue Dec 04 2012 Rex Dieter <rdieter@fedoraproject.org> - 4.9.90-1
- 4.9.90

* Mon Dec 03 2012 Than Ngo <than@redhat.com> - 4.9.4-1
- 4.9.4

* Sat Nov 03 2012 Rex Dieter <rdieter@fedoraproject.org> - 4.9.3-1
- 4.9.3

* Sun Oct 28 2012 Kevin Kofler <Kevin@tigcc.ticalc.org> - 4.9.2-2
- rebuild for OCaml 4.00.1

* Sat Sep 29 2012 Rex Dieter <rdieter@fedoraproject.org> - 4.9.2-1
- 4.9.2

* Mon Sep 03 2012 Than Ngo <than@redhat.com> - 4.9.1-1
- 4.9.1 

* Thu Aug 09 2012 Rex Dieter <rdieter@fedoraproject.org> 4.9.0-2
- rebuild (avogadro/boost)

* Thu Jul 26 2012 Lukas Tinkl <ltinkl@redhat.com> - 4.9.0-1
- 4.9.0

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.8.97-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Jul 12 2012 Rex Dieter <rdieter@fedoraproject.org> - 4.8.97-1
- 4.8.97

* Wed Jun 27 2012 Jaroslav Reznik <jreznik@redhat.com> - 4.8.95-1
- 4.8.95

* Sat Jun 09 2012 Rex Dieter <rdieter@fedoraproject.org> - 4.8.90-1
- 4.8.90
- rebuild for OCaml 4.00.0 and update ocamlopt arch list

* Fri Jun 01 2012 Jaroslav Reznik <jreznik@redhat.com> - 4.8.80-1
- 4.8.80

* Mon Apr 30 2012 Jaroslav Reznik <jreznik@redhat.com> - 4.8.3-1
- 4.8.3

* Fri Mar 30 2012 Rex Dieter <rdieter@fedoraproject.org> - 4.8.2-1
- 4.8.2

* Mon Mar 05 2012 Jaroslav Reznik <jreznik@redhat.com> - 4.8.1-1
- 4.8.1

* Sun Jan 22 2012 Rex Dieter <rdieter@fedoraproject.org> - 4.8.0-1
- 4.8.0

* Sat Jan 07 2012 Kevin Kofler <Kevin@tigcc.ticalc.org> - 4.7.97-2
- Rebuild for new OCaml (3.12.1)
- Enable facile on ARM, ocamlopt available on ARM these days

* Wed Jan 04 2012 Rex Dieter <rdieter@fedoraproject.org> - 4.7.97-1
- 4.7.97

* Thu Dec 22 2011 Radek Novacek <rnovacek@redhat.com> - 4.7.95-1
- 4.7.95

* Sun Dec 04 2011 Rex Dieter <rdieter@fedoraproject.org> - 4.7.90-1
- 4.7.90

* Fri Nov 25 2011 Rex Dieter <rdieter@fedoraproject.org> 4.7.80-1
- 4.7.80

* Sat Oct 29 2011 Rex Dieter <rdieter@fedoraproject.org> 4.7.3-1
- 4.7.3

* Wed Oct 05 2011 Rex Dieter <rdieter@fedoraproject.org> 4.7.2-1
- 4.7.2

* Sat Sep 17 2011 Rex Dieter <rdieter@fedoraproject.org> 4.7.1-1
- 4.7.1

* Tue Aug 30 2011 Rex Dieter <rdieter@fedoraproject.org> 4.7.0-10
- first try

